# See morph/grid/local/grid.nix for additional commentary.
let
  pkgs = import <nixpkgs> { };

  lib = import ../../lib;
  config = pkgs.lib.trivial.importJSON ./config.json;
  sshUsers = import ./secrets/users.nix;

  # Get absolute vpn key directory path, as a string:
  monitoringvpnKeyDir = toString ./. + "/${config.monitoringvpnKeyDir}";

  payments = {
    imports = [
      lib.issuer
      lib.hardware-aws
      (lib.customize-issuer config sshUsers monitoringvpnKeyDir "172.23.23.11" "19.03")
    ];
  };

  storage001 = let publicIPv4 = "3.120.26.190"; in {
    imports = [
      lib.storage
      ./testing001-hardware.nix
      (lib.customize-storage config sshUsers publicIPv4 monitoringvpnKeyDir "172.23.23.12" "19.03")
    ];
  };

  monitoring = let publicIPv4 = "18.156.171.217"; in {
    imports = [
      lib.monitoring
      lib.hardware-aws
      (lib.customize-monitoring hostsMap monitoringvpnKeyDir publicIPv4 "172.23.23.1" vpnClientIPs nodeExporterTargets [] "19.09")
    ];
  };

  # TBD: derive these automatically:
  hostsMap = {
    "172.23.23.1"  = [ "monitoring" "monitoring.monitoringvpn" ];
    "172.23.23.11" = [ "payments"   "payments.monitoringvpn"   ];
    "172.23.23.12" = [ "storage001" "storage001.monitoringvpn" ];
  };
  vpnClientIPs = [ "172.23.23.11" "172.23.23.12" ];
  nodeExporterTargets = [ "monitoring" "payments" "storage001" ];

in {
  network = {
    description = "PrivateStorage.io Testing Grid";
  };
  inherit payments monitoring storage001;
}
